@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic;
 
-our $DATE = '2015-07-08'; # DATE
-our $VERSION = '1.53'; # VERSION
+our $DATE = '2015-07-15'; # DATE
+our $VERSION = '1.54'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -612,6 +612,8 @@ sub action_subcommands {
 }
 
 sub action_version {
+    no strict 'refs';
+
     my ($self, $r) = @_;
 
     my $url = $r->{subcommand_data}{url} // $self->url;
@@ -628,13 +630,22 @@ sub action_version {
         ),
             ($meta->{entity_date} ? " ($meta->{entity_date})" : ""),
             "\n";
+        for my $mod (@{ $meta->{'x.dynamic_generator_modules'} // [] }) {
+            push @text, "  ", __x(
+                "{program} version {version}",
+                program => $self->_color('emphasis', $mod),
+                version => $self->_color('emphasis', (${"$mod\::VERSION"} // "?")),
+            ),
+                (${"$mod\::DATE"} ? " (".${"$mod\::DATE"}.")" : ""),
+                    "\n";
+        }
     }
 
     for my $url (@{ $self->extra_urls_for_version // [] }) {
         my $meta = $self->get_meta($r, $url);
         push @text, "  ", __x(
             "{program} version {version}",
-            program => $url,
+            program => $self->_color('emphasis', $url),
             version => $self->_color('emphasis', ($meta->{entity_v} // "?")),
         ),
             ($meta->{entity_date} ? " ($meta->{entity_date})" : ''),
@@ -767,7 +778,7 @@ Perinci::CmdLine::Classic - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.53 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-07-08.
+This document describes version 1.54 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-07-15.
 
 =head1 SYNOPSIS
 
